@@ -78,7 +78,8 @@ app.directive('retrievableKnowledgeRightColumnSummary', function($controller, $s
 
             scope.buildRetrievableKnowledge = function() {
                 FlowBuildService.openSingleComputableBuildModalFromObjectTypeAndLoc(scope, "RETRIEVABLE_KNOWLEDGE",
-                            AnyLoc.makeLoc(scope.retrievableKnowledge.projectKey, scope.retrievableKnowledge.id));
+                    AnyLoc.makeLoc(scope.retrievableKnowledge.projectKey, scope.retrievableKnowledge.id),
+                    { downstreamBuildable: scope.retrievableKnowledgeFullInfo.downstreamBuildable });
             };
 
             scope.$watch("selection.confirmedItem", function(nv, ov) {
@@ -199,6 +200,7 @@ app.controller("RetrievableKnowledgeController", function($scope, DataikuAPI, $s
         RetrievableKnowledgeUtils.updateIndexName($scope.retrievableKnowledge);
         $scope.savedSettings = angular.copy($scope.retrievableKnowledge);
         TopNav.setItem(TopNav.ITEM_RETRIEVABLE_KNOWLEDGE, $stateParams.retrievableKnowledgeId, {name: $scope.retrievableKnowledge.name});
+        TopNav.setPageTitle($scope.retrievableKnowledge.name + " - Knowledge Bank");
 
         WT1.event("llm-mesh-knowledge-bank-load", {
             retrieverType: data.retrievableKnowledge.retrieverType,
@@ -240,6 +242,7 @@ app.controller("RetrievableKnowledgeController", function($scope, DataikuAPI, $s
         AnyLoc.makeLoc($stateParams.projectKey, $scope.retrievableKnowledge.id),
         {
           redirectToJobPage: true,
+          downstreamBuildable: $scope.rkFullInfo.downstreamBuildable,
         }
       );
     };
@@ -290,15 +293,15 @@ app.constant("VECTOR_STORE_HYBRID_SUPPORT", [
 
 app.constant("RALLM_RETRIEVAL_SEARCH_TYPE_MAP", {
     'SIMILARITY': {title: 'Similarity score', description: "Retrieve the n closest documents by similarity score."},
-    'SIMILARITY_THRESHOLD': {title: 'Similarity score with threshold', description: "Retrieve all documents below the given similarity score threshold."},
+    'SIMILARITY_THRESHOLD': {title: 'Similarity score with threshold', description: "Retrieve documents with a similarity score above the defined threshold."},
     'MMR': {title: 'Improve diversity of documents', description: "Helps the selected documents to cover a wider range of information while still matching the query. Uses MMR reranking."},
     'HYBRID': {title: 'Hybrid search', description: "Combine both a similarity search and a keyword search to retrieve more relevant documents."},
 });
 
 
 app.constant("RALLM_SEARCH_INPUT_STRATEGY_MAP", {
-    'RAW_QUERY': {title: 'Raw mode', description: "Always queries the knowledge bank. For chat interactions, the input query is the full conversation history."},
-    'REWRITE_QUERY': {title: 'Smart mode', description: "Assesses first for each query if retrieving knowledge from the Knowledge Bank would be useful. If so, it reformulates the query to optimize retrieval. For chat interactions, the entire conversation history is reformulated."},
+    'RAW_QUERY': {title: 'Raw mode', description: "Always queries the knowledge bank. For chat interactions, the input query is the full conversation history.", warnIfUsedInChat: true},
+    'REWRITE_QUERY': {title: 'Smart mode', description: "Assesses first for each query if retrieving knowledge from the Knowledge Bank would be useful. If so, it reformulates the query to optimize retrieval. For chat interactions, the entire conversation history is reformulated.", warnIfUsedInChat: false},
 });
 
 app.component("printDocumentSourcesRadio", {
@@ -312,9 +315,6 @@ app.component("printDocumentSourcesRadio", {
             } else {
                 this.sourcesToPrint = "METADATA";
             }
-            this.metadataOnlyText = this.llmExposedWith.retrievalSource==='CUSTOM'?
-                "Metadata only (excluding retrieval content)" :
-                "Metadata only"
         };
 
         this.updateRagLlm = () => {
@@ -472,41 +472,37 @@ app.component('semanticRankerHelpMessage', {
 app.component('retrievalContentSettings', {
     bindings: {
         retrievableKnowledge: '<',
-        embeddingRecipeDesc: '<', // optional - used for a helpful UI message
-        availableAugmentableLLMs: '<', // optional - used for warning when non-multimodal LLM selected with multimodal retrieval column
+        embeddingRecipeDesc: '<',
+        availableAugmentableLlms: '<',
         metadataColumns: '<',
         showContentRetrieval: '<?',
         llmExposedWith: '='
     },
     templateUrl: '/templates/retrievable-knowledge/retrieval-content-settings.html',
     controller: function() {
+        const DKU_TEXT_EMBEDDING_COLUMN = 'DKU_TEXT_EMBEDDING_COLUMN';
+        const DKU_GENERATED_EMBEDDING = 'DKU_GENERATED_EMBEDDING';
         const $ctrl = this;
 
+        $ctrl.$onInit = function() {
+
+            if ($ctrl.embeddingRecipeDesc.knowledgeColumn === DKU_GENERATED_EMBEDDING) {
+                $ctrl.embeddingColumnOption = {label:"Generated embedding column", value:DKU_TEXT_EMBEDDING_COLUMN};
+            }
+            else {
+                $ctrl.embeddingColumnOption = {label:`${$ctrl.embeddingRecipeDesc.knowledgeColumn} (Embedding column)`, value:DKU_TEXT_EMBEDDING_COLUMN};
+            }
+
+            $ctrl.retrievalColumnsOptions = [
+                $ctrl.embeddingColumnOption,
+                ...$ctrl.metadataColumns.filter(col => col !== $ctrl.embeddingRecipeDesc.knowledgeColumn && col !== DKU_GENERATED_EMBEDDING).map(col => {return {value:col, label:col}})
+            ];
+        }
+
         $ctrl.hasMetadataColumns = function() {
             return $ctrl.metadataColumns && $ctrl.metadataColumns.length > 0;
         };
 
-        $ctrl.getEmbeddingRetrievalText = function () {
-            //Change embedding title as the embed column is automatically generated for KB from embed doc recipe - we don't want to display this automatic name
-            if ($ctrl.retrievableKnowledge?.multimodalColumn) {
-                return "Content embedded";
-            }
-
-            if ($ctrl.embeddingRecipeDesc) {
-                return "Same column as embedding: " + $ctrl.embeddingRecipeDesc.knowledgeColumn;
-            }
-
-            // regular embedding, but no embedding recipe -> built using the Python API
-            // use a generic name in this case
-            return "Content embedded";
-        };
-
-        $ctrl.prefillRetrievalColumn = (ragllmSettings) => {
-            if (ragllmSettings.retrievalSource === "CUSTOM" && !ragllmSettings.retrievalColumn) {
-                ragllmSettings.retrievalColumn = $ctrl.metadataColumns[0];
-            }
-        };
-
         $ctrl.disableTextGuardrails = function (ragllmSettings) {
             ragllmSettings.ragSpecificGuardrails.faithfulnessSettings.enabled = false;
             ragllmSettings.ragSpecificGuardrails.relevancySettings.enabled = false;
@@ -517,18 +513,31 @@ app.component('retrievalContentSettings', {
             ragllmSettings.ragSpecificGuardrails.multimodalRelevancySettings.enabled = false;
         };
 
-        $ctrl.shouldAlertRetrievalColumn = (ragllmSettings) => {
-            if (ragllmSettings.retrievalSource === "EMBEDDING" || ragllmSettings.retrievalSource === "MULTIMODAL" || !ragllmSettings.retrievalColumn) {
-                return false
+        $ctrl.getAlertRetrievalColumnsText = () => {
+
+            if ($ctrl.llmExposedWith.retrievalSource !== 'EMBEDDING') {
+                return undefined;
             }
-            return !$ctrl.metadataColumns.includes(ragllmSettings.retrievalColumn);
+            const columns = $ctrl.llmExposedWith.retrievalColumns || [];
+
+            if (columns.length === 0) {
+                return `No retrieval column selected, \`${$ctrl.embeddingColumnOption.label}\` will be used by default.`;
+            }
+
+            const nonAvailableColumns = columns
+                .filter(col => col !== DKU_TEXT_EMBEDDING_COLUMN && !$ctrl.metadataColumns.includes(col));
+
+            if (nonAvailableColumns.length) {
+                return `The following retrieval columns are not available in the metadata: ${nonAvailableColumns.join(', ')}. They will be ignored.`;
+            }
+            return undefined;
         };
 
         $ctrl.shouldAlertMultimodalColumn = (ragllmSettings) => {
-            if (ragllmSettings.retrievalSource !== "MULTIMODAL" || !$ctrl.availableAugmentableLLMs) {
+            if (ragllmSettings.retrievalSource !== "MULTIMODAL" || !$ctrl.availableAugmentableLlms) {
                 return false
             }
-            const selectedAugmentedLLM =  $ctrl.availableAugmentableLLMs.filter(llm => llm.id == ragllmSettings.llmId);
+            const selectedAugmentedLLM =  $ctrl.availableAugmentableLlms.filter(llm => llm.id == ragllmSettings.llmId);
             if(!selectedAugmentedLLM || !selectedAugmentedLLM.length){
                 return false;
             }
@@ -694,7 +703,8 @@ app.component('searchInputStrategySettings', {
     app.constant("SNIPPET_FORMATS", [
         {key: 'TEXT', label: 'Text', helpText: 'The snippet is plain text'},
         {key: 'MARKDOWN', label: 'Markdown', helpText: 'The snippet is in Markdown format'},
-        {key: 'HTML', label: 'HTML', helpText: 'The snippet is in HTML format'}
+        {key: 'HTML', label: 'HTML', helpText: 'The snippet is in HTML format'},
+        {key: 'JSON', label: 'JSON', helpText: 'The snippet is in Json format'}
     ])
 
     app.component('metadataSelectField', {
@@ -1055,7 +1065,6 @@ app.controller('RetrievableKnowledgeSearchController', function($scope, $compile
                             $scope.hasImages = true;
                             document.imagePaths = content.content;
                         }
-                        delete metadata.DKU_DOCUMENT_INFO;
                         delete metadata.DKU_MULTIMODAL_CONTENT;
                     }
                 });
@@ -1148,8 +1157,8 @@ app.controller('RetrievableKnowledgeSearchController', function($scope, $compile
     function getInitialSearchParams() {
         const defaultParams = RetrievableKnowledgeUtils.getRAGLLMSettings({
             maxDocuments: 10,
-            allMetadataInContext: true,
             includeScore: true,
+            includeMultimodalContent: true,
             filter: {}
         });
         const params = localStorageService.get(STORAGE_KEY) || {};
